@@ -25,8 +25,8 @@ unsigned int screen_height;
 void set_screen_size(void);
 void draw_pointer(int x, int y);
 void select_region(int x, int y, int x2, int y2);
-void select_word(int x, int y);
-void select_line(int x, int y);
+void select_words(int x, int y, int x2, int y2);
+void select_lines(int x, int y, int x2, int y2);
 void paste(void);
 void scroll(int sc);
 void set_lut(const char *word_chars);
