@@ -80,7 +80,7 @@ log_handler(struct libinput *li,
 }
 
 void
-tools_usage()
+tools_usage(void)
 {
 	printf("Usage: %s [options] [--udev [<seat>]|--device /dev/input/event0]\n"
 	       "--udev <seat>.... Use udev device discovery (default).\n"
@@ -106,7 +106,7 @@ tools_usage()
 	       "--set-scroll-method=[none|twofinger|edge|button] ... set the desired scroll method\n"
 	       "--set-scroll-button=BTN_MIDDLE ... set the button to the given button code\n"
 	       "--set-profile=[adaptive|flat].... set pointer acceleration profile\n"
-	       "--set-speed=<value>.... set pointer acceleration speed\n"
+	       "--set-speed=<value>.... set pointer acceleration speed (allowed range [-1, 1]) \n"
 	       "\n"
 	       "These options apply to all applicable devices, if a feature\n"
 	       "is not explicitly specified it is left at each device's default.\n"
@@ -185,7 +185,7 @@ tools_parse_args(int argc, char **argv, struct tools_context *context)
 			{ "set-scroll-method", 1, 0, OPT_SCROLL_METHOD },
 			{ "set-scroll-button", 1, 0, OPT_SCROLL_BUTTON },
 			{ "set-profile", 1, 0, OPT_PROFILE },
-			{ "speed", 1, 0, OPT_SPEED },
+			{ "set-speed", 1, 0, OPT_SPEED },
 			{ "word-chars", 1, 0, OPT_WORD_CHARS },
 			{ 0, 0, 0, 0}
 		};
