@@ -65,6 +65,6 @@ int tools_parse_args(int argc, char **argv, struct tools_context *context);
 struct libinput* tools_open_backend(struct tools_context *context);
 void tools_device_apply_config(struct libinput_device *device,
 			       struct tools_options *options);
-void tools_usage();
+void tools_usage(void);
 
 #endif
